default_tracker

Function default_tracker 

pub fn default_tracker() -> DefaultTracker
Available on crate feature alloc only.
Creates the DefaultTracker used by the derive macro.

Mostly an implementation detail of the derive macro, which cannot know whether the alloc feature is active at the call site.