DefaultTracker

Type Alias DefaultTracker 

pub type DefaultTracker = StandardTracker;
Available on crate feature alloc only.
The tracker used by the GetSize implementations generated by the derive macro.

This is StandardTracker if the alloc feature is active, since tracking requires an allocated set of already seen addresses. Without alloc there is no shared ownership type (Rc/Arc) to track, so NoTracker is used instead.

Aliased Type

pub struct DefaultTracker { /* private fields */ }